==> haskell-bytestring-strict-builder-0.4.5.4-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-strict-builder
version:              0.4.5.4
visibility:           public
id:                   bytestring-strict-builder-0.4.5.4-11zdVrL0bdJ5oUqk6Cr2ER
key:                  bytestring-strict-builder-0.4.5.4-11zdVrL0bdJ5oUqk6Cr2ER
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-strict-builder
synopsis:             An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.

    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".

category:             Text, ByteString, Builders, Serialization
abi:                  c9bada4b690da106201bb1a1cac7d1a2
exposed:              True
exposed-modules:      ByteString.StrictBuilder
hidden-modules:
    ByteString.StrictBuilder.Prelude
    ByteString.StrictBuilder.Population
    ByteString.StrictBuilder.Population.UncheckedShifting
    ByteString.StrictBuilder.UTF8

import-dirs:
    /usr/lib/ghc-8.10.4/site-local/bytestring-strict-builder-0.4.5.4

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/bytestring-strict-builder-0.4.5.4

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/bytestring-strict-builder-0.4.5.4

hs-libraries:         HSbytestring-strict-builder-0.4.5.4-11zdVrL0bdJ5oUqk6Cr2ER
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-strict-builder-0.4.5.4-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-strict-builder
version:              0.4.5.4
visibility:           public
id:                   bytestring-strict-builder-0.4.5.4-11yJjuO86w2KHJMyiegg5T
key:                  bytestring-strict-builder-0.4.5.4-11yJjuO86w2KHJMyiegg5T
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-strict-builder
synopsis:             An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.

    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".

category:             Text, ByteString, Builders, Serialization
abi:                  910f8e872962360e4011a33a8d49dec3
exposed:              True
exposed-modules:      ByteString.StrictBuilder
hidden-modules:
    ByteString.StrictBuilder.Prelude
    ByteString.StrictBuilder.Population
    ByteString.StrictBuilder.Population.UncheckedShifting
    ByteString.StrictBuilder.UTF8

import-dirs:
    /usr/lib/ghc-8.10.4/site-local/bytestring-strict-builder-0.4.5.4

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/bytestring-strict-builder-0.4.5.4

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/bytestring-strict-builder-0.4.5.4

hs-libraries:         HSbytestring-strict-builder-0.4.5.4-11yJjuO86w2KHJMyiegg5T
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
